@@ -162,9 +162,9 @@ def run():
     compile_id = resp.headers.get("compile_id")
     for file in z.namelist():
         if file.startswith(compile_id + '/'):
-            filename = os.path.basename(file)
+            filename = os.path.relpath(file, compile_id + '/out/')
             source = z.open(file)
-            os.makedirs(outdir, exist_ok=True)
+            os.makedirs(os.path.dirname(os.path.join(outdir, filename)), exist_ok=True)
             target = open(os.path.join(outdir, filename), "wb")
             with source, target:
                 shutil.copyfileobj(source, target)
